
load("OPG_analysis.RData")


# Section A: Forest plots of OPG and PGR

#  Data from univariate cox regression
#    unstrat.unicox
#    nodal.strat.unicox


library(rmeta)

# 1. forest plots with no lymph node stratification

# 1a.  OPG forest plot


table=unstrat.unicox

# select OPG
pval=table$pval.opg
hr=table$hr.opg
loci=table$loci.opg
upci=table$upci.opg

# reformat digits
pval=formatC(pval,digits=2)
pval=replace(pval,pval==" NA",NA)
hr=formatC(hr,digits=2)
hr=replace(hr,hr==" NA",NA)

tabletext<-cbind(c("Dataset",NA,table$dataset_labels),
                 c("n=", NA, table$ssize),
                 c("HR",NA,hr),
                 c("P-Value",NA,pval) )

# align vectors according to 2 header lines in tabletext
hr = c(NA,NA,hr)
loci = c(NA,NA,loci)
upci = c(NA,NA,upci)
ssize = c(NA,NA,table$ssize)
summ = c(FALSE,FALSE,table$pooled)


forestplot(tabletext, hr, loci,
           upci, is.summary=summ,
           clip=c(0.1, 2), xlab="HR", zero=1, 
           graphwidth=unit(3,"inches"), boxsize=ssize/300)

title(main = "OPG in ER positive BC")



# 1b.  PgR forest plot


table=unstrat.unicox

# select PgR
pval=table$pval.pgr
hr=table$hr.pgr
loci=table$loci.pgr
upci=table$upci.pgr

# reformat digits
pval=formatC(pval,digits=2)
pval=replace(pval,pval==" NA",NA)
hr=formatC(hr,digits=2)
hr=replace(hr,hr==" NA",NA)

tabletext<-cbind(c("Dataset",NA,table$dataset_labels),
                 c("n=", NA, table$ssize),
                 c("HR",NA,hr),
                 c("P-Value",NA,pval) )

# align vectors according to 2 header lines in tabletext
hr = c(NA,NA,hr)
loci = c(NA,NA,loci)
upci = c(NA,NA,upci)
ssize = c(NA,NA,table$ssize)
summ = c(FALSE,FALSE,table$pooled)


forestplot(tabletext, hr, loci,
           upci, is.summary=summ,
           clip=c(0.1, 2), xlab="HR", zero=1, 
           graphwidth=unit(3,"inches"), boxsize=ssize/300)

title(main = "PgR in ER positive BC")


# 2. forest plots with lymph node stratification


# 2a.  OPG forest plot for LNN

# select LNN
table=nodal.strat.unicox[nodal.strat.unicox$nodal==0,]

# select OPG
pval=table$pval.opg
hr=table$hr.opg
loci=table$loci.opg
upci=table$upci.opg

# reformat digits
pval=formatC(pval,digits=2)
pval=replace(pval,pval==" NA",NA)
hr=formatC(hr,digits=2)
hr=replace(hr,hr==" NA",NA)

tabletext<-cbind(c("Dataset",NA,table$dataset_labels),
                 c("n=", NA, table$ssize),
                 c("HR",NA,hr),
                 c("P-Value",NA,pval) )

# align vectors according to 2 header lines in tabletext
hr = c(NA,NA,hr)
loci = c(NA,NA,loci)
upci = c(NA,NA,upci)
ssize = c(NA,NA,table$ssize)
summ = c(FALSE,FALSE,table$pooled)


forestplot(tabletext, hr, loci,
           upci, is.summary=summ,
           clip=c(0.1, 2.5), xlab="HR", zero=1, 
           graphwidth=unit(3,"inches"), boxsize=ssize/150)

title(main = "OPG in LNN ER positive BC")






# 2b.  PgR forest plot for LNN

# select LNN
table=nodal.strat.unicox[nodal.strat.unicox$nodal==0,]

# select PgR
pval=table$pval.pgr
hr=table$hr.pgr
loci=table$loci.pgr
upci=table$upci.pgr


# reformat digits
pval=formatC(pval,digits=2)
pval=replace(pval,pval==" NA",NA)
hr=formatC(hr,digits=2)
hr=replace(hr,hr==" NA",NA)

tabletext<-cbind(c("Dataset",NA,table$dataset_labels),
                 c("n=", NA, table$ssize),
                 c("HR",NA,hr),
                 c("P-Value",NA,pval) )

# align vectors according to 2 header lines in tabletext
hr = c(NA,NA,hr)
loci = c(NA,NA,loci)
upci = c(NA,NA,upci)
ssize = c(NA,NA,table$ssize)
summ = c(FALSE,FALSE,table$pooled)


forestplot(tabletext, hr, loci,
           upci, is.summary=summ,
           clip=c(0.1, 3.5), xlab="HR", zero=1, 
           graphwidth=unit(3,"inches"), boxsize=ssize/150)

title(main = "PgR in LNN ER positive BC")





# 2c.  OPG forest plot for N+

# select N+
table=nodal.strat.unicox[nodal.strat.unicox$nodal==1,]

# select OPG
pval=table$pval.opg
hr=table$hr.opg
loci=table$loci.opg
upci=table$upci.opg

# reformat digits
pval=formatC(pval,digits=2)
pval=replace(pval,pval==" NA",NA)
hr=formatC(hr,digits=2)
hr=replace(hr,hr==" NA",NA)

tabletext<-cbind(c("Dataset",NA,table$dataset_labels),
                 c("n=", NA, table$ssize),
                 c("HR",NA,hr),
                 c("P-Value",NA,pval) )

# align vectors according to 2 header lines in tabletext
hr = c(NA,NA,hr)
loci = c(NA,NA,loci)
upci = c(NA,NA,upci)
ssize = c(NA,NA,table$ssize)
summ = c(FALSE,FALSE,table$pooled)


forestplot(tabletext, hr, loci,
           upci, is.summary=summ,
           clip=c(0.1, 2), xlab="HR", zero=1, 
           graphwidth=unit(3,"inches"), boxsize=ssize/150)

title(main = "OPG in Node positive ER positive BC")


# 2d.   PgR forest plot for N+

# select N+
table=nodal.strat.unicox[nodal.strat.unicox$nodal==1,]

# select PgR
pval=table$pval.pgr
hr=table$hr.pgr
loci=table$loci.pgr
upci=table$upci.pgr


# reformat digits
pval=formatC(pval,digits=2)
pval=replace(pval,pval==" NA",NA)
hr=formatC(hr,digits=2)
hr=replace(hr,hr==" NA",NA)

tabletext<-cbind(c("Dataset",NA,table$dataset_labels),
                 c("n=", NA, table$ssize),
                 c("HR",NA,hr),
                 c("P-Value",NA,pval) )

# align vectors according to 2 header lines in tabletext
hr = c(NA,NA,hr)
loci = c(NA,NA,loci)
upci = c(NA,NA,upci)
ssize = c(NA,NA,table$ssize)
summ = c(FALSE,FALSE,table$pooled)


forestplot(tabletext, hr, loci,
           upci, is.summary=summ,
           clip=c(0.1, 2), xlab="HR", zero=1, 
           graphwidth=unit(3,"inches"), boxsize=ssize/150)

title(main = "PgR in Node positive ER positive BC")



##########################################
##########################################



#  Section B: Correlation analysis of OPG 
#      and other genes as continous variables


# n4467.sel.df
#   data frame of normalized MAS5 expression data from 
#   selected markers for all 4467 samples

# select ER positive cases:
n2990ERpos.sel.df = n4467.sel.df[n4467.sel.df$ESR_0.0075=="ERpos",]


clu.data= n2990ERpos.sel.df[, c(3:8)]

library(simpleaffy)  # for pearson-corr based clustering

plot(standard.pearson( na.omit( clu.data)))


##########################################
